@@ -1,6 +1,6 @@
 package App::Office::Contacts::Donations::Controller;
 
-use base 'App::Office::Contacts';
+use parent 'App::Office::Contacts';
 use strict;
 use warnings;
 
@@ -12,7 +12,7 @@ use Log::Dispatch;
 
 # We don't use Moose because we isa CGI::Application.
 
-our $VERSION = '1.02';
+our $VERSION = '1.05';
 
 # -----------------------------------------------
 
@@ -20,7 +20,7 @@ sub cgiapp_prerun
 {
 	my($self) = @_;
 
-	# Outputs nothing, since logger not yet set up.
+	# Can't call, since logger not yet set up.
 	#$self -> log(debug => 'Entered cgiapp_prerun');
 
 	$self -> param(config => App::Office::Contacts::Donations::Util::Config -> new -> config);
@@ -31,11 +31,7 @@ sub cgiapp_prerun
 
 	# Set up the database.
 
-	$self -> param(db => App::Office::Contacts::Donations::Database -> new
-	(
-		config => $self -> param('config'),
-		logger => $self -> param('logger'),
-	) );
+	$self -> param(db => App::Office::Contacts::Donations::Database -> new);
 
 	# Set up the things shared by:
 	# o App::Office::Contacts
@@ -48,13 +44,17 @@ sub cgiapp_prerun
 
 	$self -> param(view => App::Office::Contacts::Donations::View -> new
 	(
-		config    => $self -> param('config'),
-		db        => $self -> param('db'),
-		logger    => $self -> param('logger'),
-		session   => $self -> param('session'),
-		tmpl_path => $self -> tmpl_path,
+		db          => $self -> param('db'),
+		script_name => $self -> script_name,
+		session     => $self -> param('session'),
+		tmpl_path   => $self -> tmpl_path,
 	) );
 
+	if ($self -> validate_post == 0)
+	{
+		$self -> prerun_mode('Initialize');
+	}
+
 } # End of cgiapp_prerun.
 
 # -----------------------------------------------
