@@ -1,6 +1,6 @@
 package App::Office::Contacts::Donations::Controller::Report;
 
-use base 'App::Office::Contacts::Donations::Controller';
+use parent 'App::Office::Contacts::Donations::Controller';
 use strict;
 use warnings;
 
@@ -8,7 +8,7 @@ use App::Office::Contacts::Controller::Exporter::Report qw/-all/;
 
 # We don't use Moose because we isa CGI::Application.
 
-our $VERSION = '1.02';
+our $VERSION = '1.05';
 
 # -----------------------------------------------
 
